import React, { useState, useEffect } from "react";
import { useNavigate } from "react-router-dom";
import { motion, AnimatePresence } from "framer-motion";
import { MessageCircle, Users, Shield, Lock, Globe, Zap, UserX, Clock, Heart, Timer, Bot, Flame } from "lucide-react";
import { useAuthStore } from '../store/auth';
import { GuestLoginModal } from '../features/auth/components/GuestLoginModal';
import { SignInModal } from '../features/auth/components/SignInModal';
import { SignUpModal } from '../features/auth/components/SignUpModal';
import { EmailVerificationModal } from '../features/auth/components/EmailVerificationModal';
import { socket } from '../lib/socket';

const HomePage: React.FC = () => {
  const navigate = useNavigate();
  const { user, isAuthenticated } = useAuthStore();
  const [showGuestModal, setShowGuestModal] = useState(false);
  const [showSignInModal, setShowSignInModal] = useState(false);
  const [showSignUpModal, setShowSignUpModal] = useState(false);
  const [showEmailVerificationModal, setShowEmailVerificationModal] = useState(false);
  const [userEmail, setUserEmail] = useState('');
  const [visibleMessages, setVisibleMessages] = useState<number>(0);
  const [typingUser, setTypingUser] = useState<'user1' | 'user2' | null>(null);
  const [progressValue, setProgressValue] = useState(0);

  // Notify server we're on the homepage to ensure proper cleanup in group chat
  useEffect(() => {
    if (socket.connected) {
      console.log('[HomePage] Updating server with current route: /');
      socket.emit('update_route', '/');
      
      // Explicit leave_group to ensure complete cleanup
      socket.emit('leave_group');
      
      // Request updated online users count
      socket.emit('request_online_users');
    } else {
      // Connect socket if not already connected
      socket.connect();
      
      // Set up event listener to request online users after connection
      const handleConnect = () => {
        console.log('[HomePage] Socket connected, requesting online users');
        socket.emit('request_online_users');
      };
      
      socket.once('connect', handleConnect);
      
      return () => {
        socket.off('connect', handleConnect);
      };
    }
  }, []);

  // Handle body scroll lock when any modal is open
  useEffect(() => {
    const isAnyModalOpen = showGuestModal || showSignInModal || showSignUpModal || showEmailVerificationModal;
    
    if (isAnyModalOpen) {
      // Store current scroll position and add styles to prevent scrolling
      const scrollY = window.scrollY;
      document.body.style.position = 'fixed';
      document.body.style.top = `-${scrollY}px`;
      document.body.style.width = '100%';
      document.body.style.overflowY = 'scroll'; // Allow scrolling within the fixed body
      document.body.style.height = '100%';
      document.body.style.pointerEvents = 'auto'; // Ensure pointer events work
    } else {
      // Restore scroll position when modals are closed
      const scrollY = document.body.style.top;
      document.body.style.position = '';
      document.body.style.top = '';
      document.body.style.width = '';
      document.body.style.overflowY = '';
      document.body.style.height = '';
      document.body.style.pointerEvents = '';
      window.scrollTo(0, parseInt(scrollY || '0') * -1);
    }

    return () => {
      // Cleanup scroll lock styles when component unmounts
      document.body.style.position = '';
      document.body.style.top = '';
      document.body.style.width = '';
      document.body.style.overflowY = '';
      document.body.style.height = '';
      document.body.style.pointerEvents = '';
    };
  }, [showGuestModal, showSignInModal, showSignUpModal, showEmailVerificationModal]);

  useEffect(() => {
    // Create progress indicator animation
    const timer = setInterval(() => {
      setProgressValue(prev => {
        if (prev >= 100) {
          return 0;
        }
        return prev + 10;
      });
    }, 1000);

    // Ensure proper cleanup
    return () => {
      clearInterval(timer);
    };
  }, []);

  const handleJoinChatRoom = () => {
    if (user) {
      // If user exists (either authenticated or guest), redirect to group chat
      navigate('/group-chat');
    } else {
      // Only show guest modal if no user exists
      setShowGuestModal(true);
    }
  };

  const handleSignIn = () => {
    setShowGuestModal(false);
    setShowSignUpModal(false);
    setShowEmailVerificationModal(false);
    setShowSignInModal(true);
  };

  const handleSignUp = () => {
    setShowGuestModal(false);
    setShowSignInModal(false);
    setShowEmailVerificationModal(false);
    setShowSignUpModal(true);
  };

  const handleSignUpSuccess = (email: string) => {
    setUserEmail(email);
    setShowSignUpModal(false);
    setShowEmailVerificationModal(true);
  };

  const allMessages = [
    { id: 1, text: "Hey! Greetings from India 🇮🇳", sender: "user1" },
    { id: 2, text: "Hello from Canada! 🇨🇦", sender: "user2" },
    { id: 3, text: "How's the weather there?", sender: "user1" },
    { id: 4, text: "Pretty cold right now! You?", sender: "user2" },
    { id: 5, text: "It's quite warm here actually!", sender: "user1" },
    { id: 6, text: "Perfect for some hot chocolate ☕", sender: "user2" },
    { id: 7, text: "Sounds cozy! What do you do there?", sender: "user1" },
    { id: 8, text: "I'm a software developer 💻", sender: "user2" },
    { id: 9, text: "That's cool! I'm into photography 📸", sender: "user1" },
  ];

  const users = {
    user1: {
      image: "https://images.unsplash.com/photo-1494790108377-be9c29b29330?q=80&w=200&h=200&auto=format&fit=crop",
      name: "Sarah"
    },
    user2: {
      image: "https://images.unsplash.com/photo-1568602471122-7832951cc4c5?q=80&w=200&h=200&auto=format&fit=crop",
      name: "David" 
    }
  };

  useEffect(() => {
    let timeoutId: NodeJS.Timeout;

    const showNextMessage = () => {
      if (visibleMessages < allMessages.length) {
        const nextMessage = allMessages[visibleMessages];
        setTypingUser(nextMessage.sender as 'user1' | 'user2');
        
        timeoutId = setTimeout(() => {
          setTypingUser(null);
          setVisibleMessages(prev => prev + 1);
        }, 1000);
      } else {
        timeoutId = setTimeout(() => {
          setVisibleMessages(0);
          setTypingUser(null);
        }, 2000);
      }
    };

    timeoutId = setTimeout(showNextMessage, typingUser ? 1000 : 2000);

    return () => clearTimeout(timeoutId);
  }, [visibleMessages, typingUser, allMessages.length]);

  const features = [
    {
      icon: UserX,
      title: "100% Anonymous",
      description: "Chat freely without sharing any personal information. No registration required.",
      color: "text-purple-600 dark:text-purple-400"
    },
    {
      icon: Shield,
      title: "Enhanced Security",
      description: "End-to-end privacy protection for all your conversations.",
      color: "text-blue-600 dark:text-blue-400"
    },
    {
      icon: Lock,
      title: "Zero Data Storage",
      description: "Messages disappear instantly. We never store your chat history.",
      color: "text-indigo-600 dark:text-indigo-400"
    },
    {
      icon: MessageCircle,
      title: "Real-time Chat",
      description: "Instant messaging with seamless delivery and typing indicators.",
      color: "text-pink-600 dark:text-pink-400"
    },
    {
      icon: Globe,
      title: "Global Reach",
      description: "Connect with people from all around the world instantly.",
      color: "text-blue-600 dark:text-blue-400"
    },
    {
      icon: Bot,
      title: "AI Chat (Coming Soon!)",
      description: "Experience intelligent conversations with our advanced AI companions.",
      color: "text-green-600 dark:text-green-400",
      badge: "Soon"
    }
  ];

  return (
    <>
      <GuestLoginModal
        isOpen={showGuestModal}
        onClose={() => setShowGuestModal(false)}
        onSignIn={handleSignIn}
        onSignUp={handleSignUp}
      />

      <SignInModal
        isOpen={showSignInModal}
        onClose={() => setShowSignInModal(false)}
        onSignUp={handleSignUp}
      />

      <SignUpModal
        isOpen={showSignUpModal}
        onClose={() => setShowSignUpModal(false)}
        onSignIn={handleSignIn}
        onSignUpSuccess={handleSignUpSuccess}
      />

      <EmailVerificationModal
        isOpen={showEmailVerificationModal}
        onClose={() => setShowEmailVerificationModal(false)}
        email={userEmail}
      />

      <div className="min-h-screen bg-gray-50 dark:bg-gray-900 transition-colors duration-300 relative">
        <section className="relative min-h-[90vh] lg:min-h-screen flex flex-col lg:flex-row items-stretch overflow-hidden">
          <div className="absolute inset-0 overflow-hidden">
            <div className="absolute inset-0 bg-gradient-to-b from-blue-50/30 to-purple-50/30 dark:from-blue-900/20 dark:to-purple-900/20 transition-colors duration-300" />
            
            <div className="absolute inset-0 hidden lg:block">
              <motion.div
                className="absolute w-64 h-64 left-1/4 top-1/4"
                animate={{
                  scale: [1, 1.2, 1],
                  rotate: [0, 45, 0],
                  opacity: [0.3, 0.5, 0.3],
                }}
                transition={{
                  duration: 8,
                  repeat: Infinity,
                  ease: "easeInOut"
                }}
              >
                <Heart className="w-full h-full text-pink-500/20 dark:text-pink-400/20" fill="currentColor" />
              </motion.div>

              <motion.div
                className="absolute w-96 h-96 right-1/4 bottom-1/4"
                animate={{
                  scale: [1.2, 1, 1.2],
                  rotate: [45, 0, 45],
                  opacity: [0.2, 0.4, 0.2],
                }}
                transition={{
                  duration: 10,
                  repeat: Infinity,
                  ease: "easeInOut",
                  delay: 1
                }}
              >
                <Heart className="w-full h-full text-purple-500/20 dark:text-purple-400/20" fill="currentColor" />
              </motion.div>

              <motion.div
                className="absolute w-48 h-48 right-1/3 top-1/3"
                animate={{
                  scale: [0.8, 1, 0.8],
                  rotate: [-45, 0, -45],
                  opacity: [0.2, 0.4, 0.2],
                }}
                transition={{
                  duration: 7,
                  repeat: Infinity,
                  ease: "easeInOut",
                  delay: 2
                }}
              >
                <Heart className="w-full h-full text-blue-500/20 dark:text-blue-400/20" fill="currentColor" />
              </motion.div>
            </div>

            <div className="absolute top-0 -left-4 w-72 h-72">
              <div className="absolute w-full h-full bg-blue-500/30 dark:bg-blue-400/20 rounded-full mix-blend-multiply filter blur-xl animate-blob" />
            </div>
            
            <div className="absolute top-0 -right-4 w-72 h-72">
              <div className="absolute w-full h-full bg-purple-500/30 dark:bg-purple-400/20 rounded-full mix-blend-multiply filter blur-xl animate-blob animation-delay-2000" />
            </div>
            
            <div className="absolute -bottom-8 left-20 w-72 h-72">
              <div className="absolute w-full h-full bg-pink-500/30 dark:bg-pink-400/20 rounded-full mix-blend-multiply filter blur-xl animate-blob animation-delay-4000" />
            </div>
          </div>

          <div className="w-full lg:w-1/2 flex items-center justify-center p-4 sm:p-8 lg:p-16 min-h-[60vh] lg:min-h-screen">
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.8 }}
              className="max-w-xl w-full space-y-8 sm:space-y-8 lg:text-left text-center pt-8 lg:pt-0"
            >
              <motion.div
                initial={{ opacity: 0 }}
                animate={{ opacity: 1 }}
                transition={{ delay: 0.2 }}
                className="text-sm sm:text-base font-medium text-blue-600 dark:text-blue-400 mb-4 lg:mb-0"
              >
                Connect Beyond Borders | Anonymous Chat
              </motion.div>
              
              <div className="lg:hidden">
                <motion.h1
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  transition={{ delay: 0.4 }}
                  className="text-4xl sm:text-5xl font-black tracking-tight text-gray-900 dark:text-gray-50 leading-tight mb-6 font-signika"
                >
                  Where Stranger Become
                  <br />
                  <span className="bg-gradient-to-r from-blue-600 to-purple-600 dark:from-blue-400 dark:to-purple-400 text-transparent bg-clip-text">
                    More Than Strangers!
                  </span>
                </motion.h1>
              </div>

              <div className="hidden lg:block">
                <motion.h1
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  transition={{ delay: 0.4 }}
                  className="text-5xl xl:text-6xl font-black tracking-tight text-gray-900 dark:text-gray-50 leading-tight font-signika"
                >
                  Where Strangers Become 
                  <br />
                  <span className="bg-gradient-to-r from-blue-600 to-purple-600 dark:from-blue-400 dark:to-purple-400 text-transparent bg-clip-text">
                   More Than Strangers
                  </span>
                </motion.h1>
              </div>

              <motion.p
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ delay: 0.6 }}
                className="text-base text-lg sm:text-xl text-xl md:text-2xl text-gray-600 dark:text-gray-300 mb-8 lg:mb-0"
              >
                Experience a random chat alternative to find friends, connect with people, and chat with strangers from all over the world!
              </motion.p>

              <motion.div
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ delay: 0.7 }}
                className="mb-8 lg:mb-0"
              >
                <div className="bg-white/10 dark:bg-gray-800/10 backdrop-blur-lg rounded-xl p-4 sm:p-6 border border-white/20 dark:border-gray-700/20 relative overflow-hidden">
                  <div className="relative z-20">
                    <div className="flex items-center gap-3 sm:gap-4 mb-4">
                      <div className="bg-blue-500/10 dark:bg-blue-400/10 rounded-md p-2">
                        <Timer className="w-5 h-5 sm:w-6 sm:h-6 text-blue-600 dark:text-blue-400" />
                      </div>
                      <div>
                        <h3 className="text-sm sm:text-base font-semibold text-gray-900 dark:text-gray-50 mb-0.5">
                          Lightning Fast Matches
                        </h3>
                        <p className="text-xs sm:text-sm text-gray-600 dark:text-gray-300">
                          100% match guarantee within 10 seconds
                        </p>
                      </div>
                    </div>

                    <div className="relative h-1.5 sm:h-2 bg-gray-200/20 dark:bg-gray-700/20 rounded-full overflow-hidden">
                      <motion.div
                        initial={{ width: 0 }}
                        animate={{ width: `${progressValue}%` }}
                        transition={{ duration: 0.5 }}
                        className="absolute inset-y-0 left-0 bg-gradient-to-r from-blue-500 to-purple-500 rounded-full"
                      />
                    </div>

                    <div className="mt-4 grid grid-cols-3 gap-2">
                      <div className="text-center">
                        <div className="text-lg sm:text-xl font-bold text-blue-600 dark:text-blue-400">
                          10s
                        </div>
                        <div className="text-[10px] sm:text-xs text-gray-600 dark:text-gray-400">Average Time</div>
                      </div>
                      <div className="text-center">
                        <div className="text-lg sm:text-xl font-bold text-purple-600 dark:text-purple-400">
                          99%
                        </div>
                        <div className="text-[10px] sm:text-xs text-gray-600 dark:text-gray-400">Success Rate</div>
                      </div>
                      <div className="text-center">
                        <div className="text-lg sm:text-xl font-bold text-pink-600 dark:text-pink-400">
                          24/7
                        </div>
                        <div className="text-[10px] sm:text-xs text-gray-600 dark:text-gray-400">Active Users</div>
                      </div>
                    </div>
                  </div>
                </div>
              </motion.div>

              <motion.div
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ delay: 0.8 }}
                className="flex flex-col sm:flex-row gap-4 pt-2 lg:justify-between justify-center relative z-30"
              >
                <motion.button
                  whileHover={{ scale: 1.02 }}
                  whileTap={{ scale: 0.98 }}
                  onClick={() => navigate("/chat")}
                  className="btn-primary px-4 sm:px-6 py-3 text-sm sm:text-base w-[80%] sm:w-full lg:w-[48%] mx-auto sm:mx-0 relative z-30"
                >
                  Start Chatting
                </motion.button>
                <motion.button
                  whileHover={{ scale: 1.02 }}
                  whileTap={{ scale: 0.98 }}
                  onClick={handleJoinChatRoom}
                  className="btn-secondary px-4 sm:px-6 py-3 text-sm sm:text-base w-[80%] sm:w-full lg:w-[48%] mx-auto sm:mx-0"
                >
                  Join Chat Room
                </motion.button>
              </motion.div>
            </motion.div>
          </div>

          <div className="hidden lg:flex w-1/2 items-center justify-center p-16">
            <motion.div
              initial={{ opacity: 0, scale: 0.95 }}
              animate={{ opacity: 1, scale: 1 }}
              transition={{ duration: 0.8, delay: 0.2 }}
              className="w-full max-w-md relative"
            >
              <motion.div 
                initial={{ opacity: 0, scale: 0.8 }}
                animate={{ opacity: 1, scale: 1 }}
                transition={{ delay: 0.4, duration: 0.5 }}
                className="absolute -right-32 top-12 z-10"
              >
                <div className="relative">
                  <img 
                    src={users.user1.image}
                    alt="Female user"
                    className="w-28 h-28 rounded-full border-4 border-white dark:border-gray-800 shadow-lg object-cover"
                  />
                  <motion.div 
                    className="absolute -inset-1 bg-blue-500/20 rounded-full blur-lg animate-blob"
                    animate={{ scale: [1, 1.1, 1], rotate: [0, 45, 0] }}
                    transition={{ duration: 5, repeat: Infinity }}
                  />
                </div>
              </motion.div>

              <motion.div 
                initial={{ opacity: 0, scale: 0.8 }}
                animate={{ opacity: 1, scale: 1 }}
                transition={{ delay: 0.6, duration: 0.5 }}
                className="absolute -left-32 bottom-12 z-10"
              >
                <div className="relative">
                  <img 
                    src={users.user2.image}
                    alt="Male user"
                    className="w-28 h-28 rounded-full border-4 border-white dark:border-gray-800 shadow-lg object-cover"
                  />
                  <motion.div 
                    className="absolute -inset-1 bg-purple-500/20 rounded-full blur-lg animate-blob"
                    animate={{ scale: [1, 1.1, 1], rotate: [0, -45, 0] }}
                    transition={{ duration: 5, repeat: Infinity, delay: 1 }}
                  />
                </div>
              </motion.div>

              <div className="bg-[#0B1120] rounded-2xl shadow-xl overflow-hidden">
                <div className="p-4 border-b border-gray-800">
                  <div className="flex items-center justify-between">
                    <div className="flex items-center gap-2">
                      <div className="w-2.5 h-2.5 bg-green-500 rounded-full"></div>
                      <span className="text-sm font-medium text-gray-300">Online Now</span>
                    </div>
                    <div className="flex items-center gap-2">
                      <Users className="w-4 h-4 text-blue-400" />
                      <span className="text-sm font-medium text-gray-300">2,345</span>
                    </div>
                  </div>
                </div>

                <div className="p-4 space-y-4 h-[520px] overflow-hidden">
                  <AnimatePresence mode="popLayout">
                    {allMessages.slice(0, visibleMessages).map((message) => (
                      <motion.div
                        key={message.id}
                        initial={{ opacity: 0, y: 20, height: 0 }}
                        animate={{ opacity: 1, y: 0, height: "auto" }}
                        exit={{ opacity: 0, height: 0 }}
                        transition={{ duration: 0.3 }}
                        className={`flex items-start gap-2 ${message.sender === 'user1' ? 'justify-end' : 'justify-start'}`}
                      >
                        <div
                          className={`max-w-xs px-4 py-2 rounded-2xl ${
                            message.sender === 'user1'
                              ? 'bg-blue-600 text-white'
                              : 'bg-[#1B2B4A] text-gray-100'
                          }`}
                        >
                          <p>{message.text}</p>
                        </div>
                      </motion.div>
                    ))}
                  </AnimatePresence>
                  
                  {typingUser && (
                    <motion.div
                      initial={{ opacity: 0 }}
                      animate={{ opacity: 1 }}
                      exit={{ opacity: 0 }}
                      className={`flex items-start gap-2 ${typingUser === 'user1' ? 'justify-end' : 'justify-start'}`}
                    >
                      <div className={`px-4 py-2 rounded-2xl ${
                        typingUser === 'user1'
                          ? 'bg-blue-600/50 text-white'
                          : 'bg-[#1B2B4A]/50 text-gray-400'
                      }`}>
                        typing...
                      </div>
                    </motion.div>
                  )}
                </div>

                <div className="p-4 border-t border-gray-800">
                  <div className="flex items-center gap-2 bg-[#1B2B4A] rounded-full px-4 py-2">
                    <input
                      type="text"
                      placeholder="Type a message..."
                      className="flex-1 bg-transparent border-none focus:outline-none text-gray-300 placeholder-gray-500"
                      disabled
                    />
                    <button className="text-blue-400">
                      <MessageCircle className="w-5 h-5" />
                    </button>
                  </div>
                </div>
              </div>
            </motion.div>
          </div>
        </section>

        <section className="py-12 sm:py-16 px-4 relative overflow-hidden bg-[#0B1120]">
          <div className="absolute inset-0 overflow-hidden">
            <div className="absolute inset-0">
              {/* Animated stars background */}
              <div className="absolute w-2 h-2 bg-blue-400 rounded-full top-1/4 left-1/4 animate-pulse"></div>
              <div className="absolute w-1 h-1 bg-purple-400 rounded-full top-1/3 left-1/2 animate-pulse animation-delay-1000"></div>
              <div className="absolute w-1.5 h-1.5 bg-yellow-400 rounded-full top-2/3 left-1/3 animate-pulse animation-delay-2000"></div>
              <div className="absolute w-2 h-2 bg-pink-400 rounded-full bottom-1/4 right-1/4 animate-pulse animation-delay-1500"></div>
              <div className="absolute w-1 h-1 bg-blue-400 rounded-full top-1/4 left-1/2 animate-pulse animation-delay-500"></div>
              <div className="absolute w-1.5 h-1.5 bg-yellow-400 rounded-full top-2/3 left-1/3 animate-pulse animation-delay-3000"></div>
            </div>
          </div>
        
          <div className="max-w-7xl mx-auto">
            <div className="text-center mb-8 sm:mb-12">
              <motion.h2 
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5 }}
                className="text-2xl sm:text-3xl md:text-4xl font-bold text-white mb-3 sm:mb-4 inline-flex items-center justify-center gap-2"
              >
                New
                <span className="bg-gradient-to-r from-blue-400 to-purple-400 text-transparent bg-clip-text">Features</span>
                <span className="relative top-0.5">
                  <span className="relative flex h-3 w-3">
                    <span className="animate-ping absolute inline-flex h-full w-full rounded-full bg-blue-400 opacity-75"></span>
                    <span className="relative inline-flex rounded-full h-3 w-3 bg-blue-500"></span>
                  </span>
                </span>
              </motion.h2>
              <motion.p 
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5, delay: 0.1 }}
                className="text-base sm:text-lg md:text-xl text-gray-300 max-w-3xl mx-auto"
              >
                Exciting new features to make your chat experience even better
              </motion.p>
            </div>

            <div className="grid grid-cols-1 md:grid-cols-2 gap-8 md:items-center">
              <motion.div 
                initial={{ opacity: 0, x: -30 }}
                whileInView={{ opacity: 1, x: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.6 }}
                className="text-white space-y-4 sm:space-y-6 order-2 md:order-1 text-center md:text-left"
              >
                <div className="space-y-3 sm:space-y-4">
                  <h3 className="text-xl sm:text-2xl md:text-3xl font-bold flex items-center flex-wrap gap-2 sm:gap-3 justify-center md:justify-start">
                    <span className="text-yellow-400">✨</span> Streak System 
                    <span className="bg-gradient-to-r from-yellow-400 to-orange-400 text-transparent bg-clip-text">Rewards</span>
                  </h3>
                  <p className="text-base sm:text-lg text-gray-300">
                    Stay connected and be rewarded! Our streak system tracks your daily activity and rewards your consistency.
                  </p>
                </div>

                <ul className="space-y-3 sm:space-y-4 mx-auto md:mx-0 max-w-xs sm:max-w-sm md:max-w-none">
                  <motion.li 
                    initial={{ opacity: 0, y: 10 }}
                    whileInView={{ opacity: 1, y: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.3, delay: 0.2 }}
                    className="flex items-center gap-3 justify-center md:justify-start"
                  >
                    <div className="flex-shrink-0 w-7 h-7 sm:w-8 sm:h-8 rounded-full bg-blue-500/20 flex items-center justify-center">
                      <span className="text-sm sm:text-base text-blue-400">🔥</span>
                    </div>
                    <span className="text-sm sm:text-base">Track your daily direct message streak with your friends</span>
                  </motion.li>
                  <motion.li 
                    initial={{ opacity: 0, y: 10 }}
                    whileInView={{ opacity: 1, y: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.3, delay: 0.3 }}
                    className="flex items-center gap-3 justify-center md:justify-start"
                  >
                    <div className="flex-shrink-0 w-7 h-7 sm:w-8 sm:h-8 rounded-full bg-purple-500/20 flex items-center justify-center">
                      <span className="text-sm sm:text-base text-purple-400">⭐</span>
                    </div>
                    <span className="text-sm sm:text-base">Earn special badges for your streak</span>
                  </motion.li>
                  <motion.li 
                    initial={{ opacity: 0, y: 10 }}
                    whileInView={{ opacity: 1, y: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.3, delay: 0.4 }}
                    className="flex items-center gap-3 justify-center md:justify-start"
                  >
                    <div className="flex-shrink-0 w-7 h-7 sm:w-8 sm:h-8 rounded-full bg-pink-500/20 flex items-center justify-center">
                      <span className="text-sm sm:text-base text-pink-400">💖</span>
                    </div>
                    <span className="text-sm sm:text-base">Stay connected with your friends</span>
                  </motion.li>
                </ul>
              </motion.div>
              
              <motion.div 
                initial={{ opacity: 0, x: 30 }}
                whileInView={{ opacity: 1, x: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.6, delay: 0.2 }}
                className="flex justify-center mb-6 md:mb-0 order-1 md:order-2"
              >
                <div className="relative w-full max-w-xs sm:max-w-sm md:max-w-md">
                  <div className="absolute inset-0 bg-gradient-to-r from-blue-600/20 to-purple-600/20 rounded-2xl blur-xl transform -rotate-3"></div>
                  <div className="relative bg-[#131B30]/80 backdrop-blur-sm border border-blue-500/20 rounded-2xl p-4 sm:p-5 overflow-hidden">
                    <div className="absolute -top-10 -left-10 w-40 h-40 bg-blue-500/10 rounded-full blur-2xl"></div>
                    <div className="absolute -bottom-10 -right-10 w-40 h-40 bg-purple-500/10 rounded-full blur-2xl"></div>
                    
                    <div className="text-center mb-6 sm:mb-8">
                      <h3 className="text-2xl sm:text-3xl font-bold text-blue-400 mb-1">Streak</h3>
                      <p className="text-sm sm:text-base text-gray-400">Stay connected, have fun!</p>
                    </div>
                    
                    <div className="space-y-3 sm:space-y-4">
                      <div className="bg-[#0B1120]/60 rounded-lg p-2.5 sm:p-3 flex items-center gap-3">
                        <div className="w-10 h-10 sm:w-12 sm:h-12 rounded-full flex items-center justify-center text-white">
                        <img 
                          src="/images/1.PNG" 
                          alt="Meet Anon Logo" 
                          className="w-14 h-14 sm:w-16 sm:h-16 object-cover"
                        />
                        </div>
                        <div className="flex-1">
                          <div className="text-white text-base sm:text-lg">@kennas</div>
                          <div className="text-yellow-400 font-bold text-sm sm:text-base">7-Day Streak!</div>
                        </div>
                      </div>
                      
                      <div className="bg-[#0B1120]/60 rounded-lg p-2.5 sm:p-3 flex items-center gap-3">
                        <div className="w-10 h-10 sm:w-12 sm:h-12 rounded-full flex items-center justify-center text-white">
                        <img 
                          src="/images/2.PNG" 
                          alt="Meet Anon Logo" 
                          className="w-14 h-14 sm:w-16 sm:h-16 object-cover"
                        />
                        </div>
                        <div className="flex-1">
                          <div className="text-white text-base sm:text-lg">@bella</div>
                          <div className="text-white font-bold text-sm sm:text-base">3-Day Streak!</div>
                        </div>
                      </div>
                      
                      <div className="bg-[#0B1120]/60 rounded-lg p-2.5 sm:p-3 flex items-center gap-3">
                        <div className="w-10 h-10 sm:w-12 sm:h-12 rounded-full flex items-center justify-center text-white">
                        <img 
                          src="/images/3.PNG" 
                          alt="Meet Anon Logo" 
                          className="w-14 h-14 sm:w-16 sm:h-16 object-cover"
                        />
                        </div>
                        <div className="flex-1">
                          <div className="text-white text-base sm:text-lg">@nova</div>
                          <div className="text-yellow-400 font-bold text-sm sm:text-base">1-Day Streak!</div>
                        </div>
                      </div>
                    </div>
                    
                    <div className="absolute bottom-1 -right-2">
                      <div className="text-orange-500 transform rotate-12 text-4xl sm:text-5xl">🔥</div>
                    </div>
                  </div>
                </div>
              </motion.div>
            </div>
          </div>
        </section>

        <section className="py-12 sm:py-16 px-4 relative overflow-hidden bg-[#131B30]">
          <div className="absolute inset-0 overflow-hidden">
            <div className="absolute inset-0">
              {/* Animated stars background */}
              <div className="absolute w-2 h-2 bg-blue-400 rounded-full top-1/5 right-1/4 animate-pulse"></div>
              <div className="absolute w-1 h-1 bg-purple-400 rounded-full top-1/2 right-1/3 animate-pulse animation-delay-1000"></div>
              <div className="absolute w-1.5 h-1.5 bg-yellow-400 rounded-full bottom-1/4 right-1/2 animate-pulse animation-delay-2000"></div>
              <div className="absolute w-2 h-2 bg-pink-400 rounded-full bottom-1/3 left-1/4 animate-pulse animation-delay-1500"></div>
              <div className="absolute w-1 h-1 bg-blue-400 rounded-full top-1/4 left-1/2 animate-pulse animation-delay-500"></div>
              <div className="absolute w-1.5 h-1.5 bg-yellow-400 rounded-full top-2/3 left-1/3 animate-pulse animation-delay-3000"></div>
            </div>
          </div>

          <div className="max-w-7xl mx-auto">
            <div className="text-center mb-8 sm:mb-12">
              <motion.h2 
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5 }}
                className="text-2xl sm:text-3xl md:text-4xl font-bold text-white mb-3 sm:mb-4"
              >
                Leaderboard <span className="bg-gradient-to-r from-yellow-400 to-orange-400 text-transparent bg-clip-text">top #10</span>
              </motion.h2>
              <motion.p 
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5, delay: 0.1 }}
                className="text-base sm:text-lg text-gray-300 max-w-3xl mx-auto"
              >
                Compete with other users and climb the ranks to become a chat champion
              </motion.p>
            </div>

            <motion.div
              initial={{ opacity: 0, y: 30 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ duration: 0.6 }}
              className="relative max-w-3xl mx-auto"
            >
              <div className="absolute inset-0 bg-gradient-to-r from-blue-600/20 via-purple-600/20 to-pink-600/20 rounded-2xl blur-xl transform -rotate-1"></div>
              <div className="relative bg-[#0B1120] border border-gray-800/50 rounded-xl overflow-hidden backdrop-blur-sm">
                {/* Leaderboard Header */}
                <div className="flex items-center px-4 py-2 border-b border-gray-800/50 text-gray-300 text-sm">
                  <div className="w-8 flex-shrink-0 mr-2 pt-1">#</div>
                  <div className="flex-grow h-12 pt-4">User</div>
                  <div className="w-24 text-center">Streak</div>
                  <div className="w-20 text-right">Badge</div>
                </div>

                {/* Leaderboard Rows */}
                <div className="divide-y divide-gray-800/50">
                  {/* User 1 - First place */}
                  <motion.div 
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.4, delay: 0.1 }}
                    className="flex items-center p-4 hover:bg-gray-800/20 transition-colors"
                  >
                    <div className="w-8 flex-shrink-0 mr-2">
                      <div className="w-6 h-6 rounded-full bg-yellow-500 flex items-center justify-center text-gray-900 text-xs font-bold">1</div>
                    </div>
                    <div className="flex-grow flex items-center gap-3">
                      <div className="w-8 h-8 rounded-full bg-gradient-to-r from-blue-500 to-purple-500 flex-shrink-0 flex items-center justify-center text-white">
                        <span className="text-sm font-semibold">K</span>
                      </div>
                      <span className="text-white font-medium truncate">Kieran</span>
                    </div>
                    <div className="w-24 text-right text-gray-300 flex items-center justify-center gap-1">
                      <Flame className="h-4 w-4 text-orange-500 fill-orange-500" />
                      <span>78</span>
                    </div>
                    <div className="w-20 text-right flex items-center justify-end">
                      <div className="relative group">
                        <img 
                          src="/badges/60-days-streak.png" 
                          alt="Streak Badge" 
                          className="w-12 h-12 object-contain"
                        />
                        <div className="absolute bottom-full right-0 mb-2 hidden group-hover:block">
                          <div className="bg-gray-900 text-white text-xs rounded py-1 px-2 whitespace-nowrap">
                            7 Day Streak Achievement
                          </div>
                          <div className="absolute right-2 top-full w-2 h-2 bg-gray-900 transform rotate-45"></div>
                        </div>
                      </div>
                    </div>
                  </motion.div>

                  {/* User 2 - Second place */}
                  <motion.div 
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.4, delay: 0.2 }}
                    className="flex items-center p-4 hover:bg-gray-800/20 transition-colors"
                  >
                    <div className="w-8 flex-shrink-0 mr-2">
                      <div className="w-6 h-6 rounded-full bg-gray-400 flex items-center justify-center text-gray-900 text-xs font-bold">2</div>
                    </div>
                    <div className="flex-grow flex items-center gap-3">
                      <div className="w-8 h-8 rounded-full bg-gradient-to-r from-pink-500 to-red-500 flex-shrink-0 flex items-center justify-center text-white">
                        <span className="text-sm font-semibold">T</span>
                      </div>
                      <span className="text-white font-medium truncate">Techno</span>
                    </div>
                    <div className="w-24 text-right text-gray-300 flex items-center justify-center gap-1">
                      <Flame className="h-4 w-4 text-orange-500 fill-orange-500" />
                      <span>41</span>
                    </div>
                    <div className="w-20 text-right flex items-center justify-end">
                      <div className="relative group">
                        <img 
                          src="/badges/30-days-streak.png" 
                          alt="Streak Badge" 
                          className="w-12 h-12 object-contain"
                        />
                        <div className="absolute bottom-full right-0 mb-2 hidden group-hover:block">
                          <div className="bg-gray-900 text-white text-xs rounded py-1 px-2 whitespace-nowrap">
                            7 Day Streak Achievement
                          </div>
                          <div className="absolute right-2 top-full w-2 h-2 bg-gray-900 transform rotate-45"></div>
                        </div>
                      </div>
                    </div>
                  </motion.div>

                  {/* User 3 - Third place */}
                  <motion.div 
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.4, delay: 0.3 }}
                    className="flex items-center p-4 hover:bg-gray-800/20 transition-colors"
                  >
                    <div className="w-8 flex-shrink-0 mr-2">
                      <div className="w-6 h-6 rounded-full bg-orange-500 flex items-center justify-center text-gray-900 text-xs font-bold">3</div>
                    </div>
                    <div className="flex-grow flex items-center gap-3">
                      <div className="w-8 h-8 rounded-full bg-gradient-to-r from-orange-500 to-yellow-500 flex-shrink-0 flex items-center justify-center text-white">
                        <span className="text-sm font-semibold">L</span>
                      </div>
                      <span className="text-white font-medium truncate">Luuk</span>
                    </div>
                    <div className="w-24 text-right text-gray-300 flex items-center justify-center gap-1">
                      <Flame className="h-4 w-4 text-orange-500 fill-orange-500" />
                      <span>15</span>
                    </div>
                    <div className="w-20 text-right flex items-center justify-end">
                      <div className="relative group">
                        <img 
                          src="/badges/14-days-streak.png" 
                          alt="Streak Badge" 
                          className="w-12 h-12 object-contain"
                        />
                        <div className="absolute bottom-full right-0 mb-2 hidden group-hover:block">
                          <div className="bg-gray-900 text-white text-xs rounded py-1 px-2 whitespace-nowrap">
                            3 Day Streak Achievement
                          </div>
                          <div className="absolute right-2 top-full w-2 h-2 bg-gray-900 transform rotate-45"></div>
                        </div>
                      </div>
                    </div>
                  </motion.div>

                  {/* User 4 - Fourth place */}
                  <motion.div 
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.4, delay: 0.4 }}
                    className="flex items-center p-4 hover:bg-gray-800/20 transition-colors"
                  >
                    <div className="w-8 flex-shrink-0 mr-2">
                      <div className="w-6 h-6 rounded-full bg-gray-700 flex items-center justify-center text-gray-300 text-xs font-bold">4</div>
                    </div>
                    <div className="flex-grow flex items-center gap-3">
                      <div className="w-8 h-8 rounded-full bg-gradient-to-r from-blue-600 to-cyan-500 flex-shrink-0 flex items-center justify-center text-white">
                        <span className="text-sm font-semibold">I</span>
                      </div>
                      <span className="text-white font-medium truncate">IceRush</span>
                    </div>
                    <div className="w-24 text-right text-gray-300 flex items-center justify-center gap-1">
                      <Flame className="h-4 w-4 text-orange-500 fill-orange-500" />
                      <span>3</span>
                    </div>
                    <div className="w-20 text-right flex items-center justify-end">
                      <div className="relative group">
                        <img 
                          src="/badges/3-days-streak.png" 
                          alt="Streak Badge" 
                          className="w-12 h-12 object-contain"
                        />
                        <div className="absolute bottom-full right-0 mb-2 hidden group-hover:block">
                          <div className="bg-gray-900 text-white text-xs rounded py-1 px-2 whitespace-nowrap">
                            1 Day Streak Achievement
                          </div>
                          <div className="absolute right-2 top-full w-2 h-2 bg-gray-900 transform rotate-45"></div>
                        </div>
                      </div>
                    </div>
                  </motion.div>
                </div>

                {/* View More Label */}
                <div className="bg-gradient-to-r from-blue-900/60 via-purple-900/60 to-blue-900/60 p-3 text-center relative overflow-hidden">
                  <div className="absolute inset-0 flex items-center justify-center opacity-5 pb-5">
                    <svg className="w-full h-32" viewBox="0 0 100 20">
                      <text x="50%" y="15" dominantBaseline="middle" textAnchor="middle" fontSize="12" fill="currentColor" className="text-white">Leaderboard</text>
                    </svg>
                  </div>
                  <div className="relative z-10 flex items-center justify-center gap-2">
                    <div className="text-xs sm:text-sm font-semibold text-blue-300">Live Now</div>
                    <div className="relative flex h-2 w-2">
                      <span className="animate-ping absolute inline-flex h-full w-full rounded-full bg-blue-400 opacity-75"></span>
                      <span className="relative inline-flex rounded-full h-2 w-2 bg-blue-500"></span>
                    </div>
                  </div>
                </div>
              </div>
              
              {/* Decorative elements */}
              <div className="absolute -bottom-6 -right-3 text-4xl">🏆</div>
              <div className="absolute -top-6 -left-3 text-4xl">⭐</div>
            </motion.div>
            
            <div className="text-center mt-8">
              <motion.p
                initial={{ opacity: 0, y: 10 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5, delay: 0.6 }}
                className="text-gray-300 text-sm sm:text-base"
              >
                Active users will earn badges through Direct Messaging
              </motion.p>
            </div>
          </div>
        </section>

        <section className="py-12 sm:py-16 px-4 relative overflow-hidden bg-[#0F172A]">
          <div className="absolute inset-0 overflow-hidden">
            <div className="absolute inset-0">
              {/* Animated stars background */}
              <div className="absolute w-2 h-2 bg-pink-400 rounded-full top-1/4 right-1/3 animate-pulse"></div>
              <div className="absolute w-1 h-1 bg-blue-400 rounded-full top-1/3 right-1/4 animate-pulse animation-delay-1000"></div>
              <div className="absolute w-1.5 h-1.5 bg-purple-400 rounded-full bottom-1/3 right-1/5 animate-pulse animation-delay-2000"></div>
              <div className="absolute w-2 h-2 bg-yellow-400 rounded-full bottom-1/4 left-1/3 animate-pulse animation-delay-1500"></div>
              <div className="absolute w-1 h-1 bg-pink-400 rounded-full top-1/5 left-1/4 animate-pulse animation-delay-500"></div>
              <div className="absolute w-1.5 h-1.5 bg-indigo-400 rounded-full top-1/2 left-1/5 animate-pulse animation-delay-3000"></div>
            </div>
          </div>

          <div className="max-w-7xl mx-auto">
            <div className="text-center mb-8 sm:mb-12">
              <motion.h2 
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5 }}
                className="text-2xl sm:text-3xl md:text-4xl font-bold text-white mb-3 sm:mb-4"
              >
                Confession <span className="bg-gradient-to-r from-pink-400 to-purple-400 text-transparent bg-clip-text">Wall</span>
              </motion.h2>
              <motion.p 
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5, delay: 0.1 }}
                className="text-base sm:text-lg text-gray-300 max-w-3xl mx-auto"
              >
                Share your secrets anonymously and see what others think
              </motion.p>
            </div>

            <div className="grid grid-cols-1 md:grid-cols-2 gap-8 md:items-center">
              <motion.div 
                initial={{ opacity: 0, x: -30 }}
                whileInView={{ opacity: 1, x: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.6 }}
                className="text-white space-y-4 sm:space-y-6 order-2 md:order-1 text-center md:text-left"
              >
                <div className="space-y-3 sm:space-y-4">
                  <h3 className="text-xl sm:text-2xl md:text-3xl font-bold flex items-center flex-wrap gap-2 sm:gap-3 justify-center md:justify-start">
                    <span className="text-pink-400">💌</span> Anonymous 
                    <span className="bg-gradient-to-r from-pink-400 to-purple-400 text-transparent bg-clip-text">Confessions</span>
                  </h3>
                  <p className="text-base sm:text-lg text-gray-300">
                    Express yourself freely without judgment. Share your thoughts, secrets, and stories completely anonymously.
                  </p>
                </div>

                <ul className="space-y-3 sm:space-y-4 mx-auto md:mx-0 max-w-xs sm:max-w-sm md:max-w-none">
                  <motion.li 
                    initial={{ opacity: 0, y: 10 }}
                    whileInView={{ opacity: 1, y: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.3, delay: 0.2 }}
                    className="flex items-center gap-3 justify-center md:justify-start"
                  >
                    <div className="flex-shrink-0 w-7 h-7 sm:w-8 sm:h-8 rounded-full bg-pink-500/20 flex items-center justify-center">
                      <span className="text-sm sm:text-base text-pink-400">🔒</span>
                    </div>
                    <span className="text-sm sm:text-base">100% anonymous sharing</span>
                  </motion.li>
                  <motion.li 
                    initial={{ opacity: 0, y: 10 }}
                    whileInView={{ opacity: 1, y: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.3, delay: 0.3 }}
                    className="flex items-center gap-3 justify-center md:justify-start"
                  >
                    <div className="flex-shrink-0 w-7 h-7 sm:w-8 sm:h-8 rounded-full bg-purple-500/20 flex items-center justify-center">
                      <span className="text-sm sm:text-base text-purple-400">❤️</span>
                    </div>
                    <span className="text-sm sm:text-base">React and comment on confessions</span>
                  </motion.li>
                  <motion.li 
                    initial={{ opacity: 0, y: 10 }}
                    whileInView={{ opacity: 1, y: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.3, delay: 0.4 }}
                    className="flex items-center gap-3 justify-center md:justify-start"
                  >
                    <div className="flex-shrink-0 w-7 h-7 sm:w-8 sm:h-8 rounded-full bg-indigo-500/20 flex items-center justify-center">
                      <span className="text-sm sm:text-base text-indigo-400">🎭</span>
                    </div>
                    <span className="text-sm sm:text-base">Find comfort in shared experiences</span>
                  </motion.li>
                </ul>
              </motion.div>
              
              <motion.div 
                initial={{ opacity: 0, x: 30 }}
                whileInView={{ opacity: 1, x: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.6, delay: 0.2 }}
                className="flex justify-center mb-6 md:mb-0 order-1 md:order-2"
              >
                <div className="relative w-full max-w-xs sm:max-w-sm md:max-w-md">
                  <div className="absolute inset-0 bg-gradient-to-r from-pink-600/20 to-purple-600/20 rounded-2xl blur-xl transform -rotate-3"></div>
                  <div className="relative bg-[#1A1F35]/80 backdrop-blur-sm border border-purple-500/20 rounded-2xl p-4 sm:p-5 overflow-hidden">
                    <div className="absolute -top-10 -left-10 w-40 h-40 bg-pink-500/10 rounded-full blur-2xl"></div>
                    <div className="absolute -bottom-10 -right-10 w-40 h-40 bg-indigo-500/10 rounded-full blur-2xl"></div>
                    
                    <div className="text-center mb-6">
                      <h3 className="text-2xl sm:text-3xl font-bold text-pink-400 mb-1">Confessions</h3>
                      <p className="text-sm sm:text-base text-gray-400">Share anonymously, connect genuinely</p>
                    </div>
                    
                    <div className="space-y-3 sm:space-y-4">
                      <div className="bg-[#0F172A]/80 rounded-lg p-3 sm:p-4">
                        <p className="text-gray-300 text-sm sm:text-base mb-2">I've been pretending to like coffee for 5 years just to fit in at work. I actually hate it and secretly drink hot chocolate in my coffee mug.</p>
                        <div className="flex items-center justify-between mt-2">
                          <div className="flex items-center gap-1 sm:gap-2">
                            <button className="flex items-center gap-1 text-pink-400 text-xs sm:text-sm bg-pink-500/10 px-2 py-1 rounded-full">
                              <span>❤️</span> 24
                            </button>
                            <button className="flex items-center gap-1 text-yellow-400 text-xs sm:text-sm bg-yellow-500/10 px-2 py-1 rounded-full">
                              <span>😂</span> 56
                            </button>
                            <button className="flex items-center gap-1 text-blue-400 text-xs sm:text-sm bg-blue-500/10 px-2 py-1 rounded-full">
                              <span>😮</span> 12
                            </button>
                          </div>
                          <span className="text-gray-500 text-xs">2 hours ago</span>
                        </div>
                      </div>
                      
                      <div className="bg-[#0F172A]/80 rounded-lg p-3 sm:p-4">
                        <p className="text-gray-300 text-sm sm:text-base mb-2">I'm secretly learning to play the guitar to surprise my partner on our anniversary, but I'm terrible at it. I practice when they're not home.</p>
                        <div className="flex items-center justify-between mt-2">
                          <div className="flex items-center gap-1 sm:gap-2">
                            <button className="flex items-center gap-1 text-pink-400 text-xs sm:text-sm bg-pink-500/10 px-2 py-1 rounded-full">
                              <span>❤️</span> 78
                            </button>
                            <button className="flex items-center gap-1 text-yellow-400 text-xs sm:text-sm bg-yellow-500/10 px-2 py-1 rounded-full">
                              <span>🥺</span> 34
                            </button>
                            <button className="flex items-center gap-1 text-blue-400 text-xs sm:text-sm bg-blue-500/10 px-2 py-1 rounded-full">
                              <span>👍</span> 45
                            </button>
                          </div>
                          <span className="text-gray-500 text-xs">5 hours ago</span>
                        </div>
                      </div>
                      
                      <div className="bg-[#0F172A]/80 rounded-lg p-3 sm:p-4">
                        <p className="text-gray-300 text-sm sm:text-base mb-2">I told everyone I'm busy with work, but I actually took a day off to binge watch an entire season of my favorite show without interruptions.</p>
                        <div className="flex items-center justify-between mt-2">
                          <div className="flex items-center gap-1 sm:gap-2">
                            <button className="flex items-center gap-1 text-pink-400 text-xs sm:text-sm bg-pink-500/10 px-2 py-1 rounded-full">
                              <span>❤️</span> 32
                            </button>
                            <button className="flex items-center gap-1 text-yellow-400 text-xs sm:text-sm bg-yellow-500/10 px-2 py-1 rounded-full">
                              <span>😂</span> 89
                            </button>
                            <button className="flex items-center gap-1 text-purple-400 text-xs sm:text-sm bg-purple-500/10 px-2 py-1 rounded-full">
                              <span>✨</span> 17
                            </button>
                          </div>
                          <span className="text-gray-500 text-xs">12 hours ago</span>
                        </div>
                      </div>
                    </div>
                    
                    <div className="mt-4 relative">
                      <input 
                        type="text" 
                        placeholder="Type your confession..." 
                        className="w-full bg-[#0F172A]/50 border border-gray-700/50 rounded-full py-2 px-4 text-sm text-gray-300 placeholder-gray-500 focus:outline-none focus:ring-2 focus:ring-purple-500/50"
                        disabled
                      />
                      </div>
                  </div>
                </div>
              </motion.div>
            </div>
          </div>
        </section>

        <section className="py-20 px-4 relative overflow-hidden">
          <div className="max-w-7xl mx-auto">
            <div className="text-center mb-10 sm:mb-16">
              <h2 className="text-2xl sm:text-3xl md:text-4xl font-bold text-gray-900 dark:text-gray-50 mb-2 sm:mb-4">
                Everything you need to connect
              </h2>
              <p className="text-base sm:text-lg md:text-xl text-gray-600 dark:text-gray-300 max-w-3xl mx-auto">
                Discover all the features that make chatting more enjoyable
              </p>
            </div>

            <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4 sm:gap-6 lg:gap-8">
              {features.map((feature, index) => (
                <motion.div
                  key={feature.title}
                  initial={{ opacity: 0, y: 20 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  viewport={{ once: true }}
                  transition={{ duration: 0.5, delay: index * 0.1 }}
                  className="card-base p-4 sm:p-5 md:p-6 relative overflow-hidden group hover:scale-[1.02] transition-transform duration-300"
                >
                  <div className="relative z-10 flex flex-col items-center text-center">
                    <feature.icon className={`w-10 h-10 sm:w-11 sm:h-11 md:w-12 md:h-12 mb-3 sm:mb-4 ${feature.color}`} />
                    <h3 className="text-lg sm:text-xl font-semibold mb-1 sm:mb-2 text-gray-900 dark:text-gray-50 flex items-center flex-wrap justify-center gap-2">
                      {feature.title}
                      {feature.badge && (
                        <span className="px-2 py-0.5 sm:py-1 text-xs font-medium bg-green-100 dark:bg-green-900 text-green-800 dark:text-green-200 rounded-full">
                          {feature.badge}
                        </span>
                      )}
                    </h3>
                    <p className="text-sm sm:text-base text-gray-600 dark:text-gray-300">
                      {feature.description}
                    </p>
                  </div>
                  <div className="absolute inset-0 bg-gradient-to-r from-blue-50/0 via-blue-50/30 to-blue-50/0 dark:from-blue-900/0 dark:via-blue-900/30 dark:to-blue-900/0 transform translate-x-[-100%] group-hover:translate-x-[100%] transition-transform duration-1000" />
                </motion.div>
              ))}
            </div>
          </div>
        </section>

        <section className="py-20 px-4 relative overflow-hidden">
          <div className="absolute inset-0 bg-gradient-to-r from-blue-100/50 to-purple-100/50 dark:from-blue-900/20 dark:to-purple-900/20 transition-colors duration-300" />
          
          <div className="max-w-4xl mx-auto text-center relative z-10">
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5 }}
              className="mb-8"
            >
              <h2 className="text-3xl sm:text-4xl font-bold mb-4 text-gray-900 dark:text-gray-50">
                Ready to Start Chatting?
              </h2>
              <p className="text-xl text-gray-600 dark:text-gray-300">
                Join millions of users already connecting on our platform
              </p>
            </motion.div>

            <motion.button
              whileHover={{ scale: 1.02 }}
              whileTap={{ scale: 0.98 }}
              onClick={() => navigate("/chat")}
              className="btn-primary px-4 sm:px-6 py-3 text-sm sm:text-base w-[80%] sm:w-full lg:w-[48%] mx-auto sm:mx-0 relative z-30"
            >
              Start Chatting
            </motion.button>
          </div>
        </section>
      </div>
    </>
  );
};

export default HomePage;